#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_notification_stream(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def BGPSessionState_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_BGPPeerIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        BGPPeerIpAddress = ET.SubElement(BGPSessionState, "BGPPeerIpAddress")
        BGPPeerIpAddress.text = kwargs.pop('BGPPeerIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_BGPPeerState(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        BGPPeerState = ET.SubElement(BGPSessionState, "BGPPeerState")
        BGPPeerState.text = kwargs.pop('BGPPeerState')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_BGPNeighborIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        BGPNeighborIpAddress = ET.SubElement(BGPNeighborPrefixExceeded, "BGPNeighborIpAddress")
        BGPNeighborIpAddress.text = kwargs.pop('BGPNeighborIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_neighborPrefixLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        neighborPrefixLimit = ET.SubElement(BGPNeighborPrefixExceeded, "neighborPrefixLimit")
        neighborPrefixLimit.text = kwargs.pop('neighborPrefixLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_RIBRouteLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        RIBRouteLimit = ET.SubElement(RIBSystemRouteLimitExceeded, "RIBRouteLimit")
        RIBRouteLimit.text = kwargs.pop('RIBRouteLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_RIBNextHopLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        RIBNextHopLimit = ET.SubElement(RIBNextHopLimitExceeded, "RIBNextHopLimit")
        RIBNextHopLimit.text = kwargs.pop('RIBNextHopLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_TunnelDestinationIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        TunnelDestinationIpAddress = ET.SubElement(VxLANTunnelState, "TunnelDestinationIpAddress")
        TunnelDestinationIpAddress.text = kwargs.pop('TunnelDestinationIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_TunnelState(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        TunnelState = ET.SubElement(VxLANTunnelState, "TunnelState")
        TunnelState.text = kwargs.pop('TunnelState')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_OSPFNeighborIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        OSPFNeighborIpAddress = ET.SubElement(OSPFNeighborState, "OSPFNeighborIpAddress")
        OSPFNeighborIpAddress.text = kwargs.pop('OSPFNeighborIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_NeighborState(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        NeighborState = ET.SubElement(OSPFNeighborState, "NeighborState")
        NeighborState.text = kwargs.pop('NeighborState')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_NewMasterIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        NewMasterIpAddress = ET.SubElement(VRRPNewMaster, "NewMasterIpAddress")
        NewMasterIpAddress.text = kwargs.pop('NewMasterIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_VRRPSessionId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        VRRPSessionId = ET.SubElement(VRRPNewMaster, "VRRPSessionId")
        VRRPSessionId.text = kwargs.pop('VRRPSessionId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_VRFName(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        VRFName = ET.SubElement(RIBVRFRouteLimitExceeded, "VRFName")
        VRFName.text = kwargs.pop('VRFName')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_RIBVRFRouteLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        RIBVRFRouteLimit = ET.SubElement(RIBVRFRouteLimitExceeded, "RIBVRFRouteLimit")
        RIBVRFRouteLimit.text = kwargs.pop('RIBVRFRouteLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_ARPLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        ARPLimit = ET.SubElement(ARPLimitExceeded, "ARPLimit")
        ARPLimit.text = kwargs.pop('ARPLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_NDLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        NDLimit = ET.SubElement(NDLimitExceeded, "NDLimit")
        NDLimit.text = kwargs.pop('NDLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPSessionState, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_BGPPeerIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        BGPPeerIpAddress = ET.SubElement(BGPSessionState, "BGPPeerIpAddress")
        BGPPeerIpAddress.text = kwargs.pop('BGPPeerIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPSessionState_BGPPeerState(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPSessionState = ET.SubElement(config, "BGPSessionState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        BGPPeerState = ET.SubElement(BGPSessionState, "BGPPeerState")
        BGPPeerState.text = kwargs.pop('BGPPeerState')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(BGPNeighborPrefixExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_BGPNeighborIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        BGPNeighborIpAddress = ET.SubElement(BGPNeighborPrefixExceeded, "BGPNeighborIpAddress")
        BGPNeighborIpAddress.text = kwargs.pop('BGPNeighborIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def BGPNeighborPrefixExceeded_neighborPrefixLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        BGPNeighborPrefixExceeded = ET.SubElement(config, "BGPNeighborPrefixExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        neighborPrefixLimit = ET.SubElement(BGPNeighborPrefixExceeded, "neighborPrefixLimit")
        neighborPrefixLimit.text = kwargs.pop('neighborPrefixLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBSystemRouteLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBSystemRouteLimitExceeded_RIBRouteLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBSystemRouteLimitExceeded = ET.SubElement(config, "RIBSystemRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        RIBRouteLimit = ET.SubElement(RIBSystemRouteLimitExceeded, "RIBRouteLimit")
        RIBRouteLimit.text = kwargs.pop('RIBRouteLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBNextHopLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBNextHopLimitExceeded_RIBNextHopLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBNextHopLimitExceeded = ET.SubElement(config, "RIBNextHopLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        RIBNextHopLimit = ET.SubElement(RIBNextHopLimitExceeded, "RIBNextHopLimit")
        RIBNextHopLimit.text = kwargs.pop('RIBNextHopLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VxLANTunnelState, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_TunnelDestinationIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        TunnelDestinationIpAddress = ET.SubElement(VxLANTunnelState, "TunnelDestinationIpAddress")
        TunnelDestinationIpAddress.text = kwargs.pop('TunnelDestinationIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VxLANTunnelState_TunnelState(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VxLANTunnelState = ET.SubElement(config, "VxLANTunnelState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        TunnelState = ET.SubElement(VxLANTunnelState, "TunnelState")
        TunnelState.text = kwargs.pop('TunnelState')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(OSPFNeighborState, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_OSPFNeighborIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        OSPFNeighborIpAddress = ET.SubElement(OSPFNeighborState, "OSPFNeighborIpAddress")
        OSPFNeighborIpAddress.text = kwargs.pop('OSPFNeighborIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def OSPFNeighborState_NeighborState(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        OSPFNeighborState = ET.SubElement(config, "OSPFNeighborState", xmlns="http://brocade.com/ns/brocade-notification-stream")
        NeighborState = ET.SubElement(OSPFNeighborState, "NeighborState")
        NeighborState.text = kwargs.pop('NeighborState')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(VRRPNewMaster, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_NewMasterIpAddress(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        NewMasterIpAddress = ET.SubElement(VRRPNewMaster, "NewMasterIpAddress")
        NewMasterIpAddress.text = kwargs.pop('NewMasterIpAddress')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def VRRPNewMaster_VRRPSessionId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        VRRPNewMaster = ET.SubElement(config, "VRRPNewMaster", xmlns="http://brocade.com/ns/brocade-notification-stream")
        VRRPSessionId = ET.SubElement(VRRPNewMaster, "VRRPSessionId")
        VRRPSessionId.text = kwargs.pop('VRRPSessionId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(RIBVRFRouteLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_VRFName(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        VRFName = ET.SubElement(RIBVRFRouteLimitExceeded, "VRFName")
        VRFName.text = kwargs.pop('VRFName')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def RIBVRFRouteLimitExceeded_RIBVRFRouteLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        RIBVRFRouteLimitExceeded = ET.SubElement(config, "RIBVRFRouteLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        RIBVRFRouteLimit = ET.SubElement(RIBVRFRouteLimitExceeded, "RIBVRFRouteLimit")
        RIBVRFRouteLimit.text = kwargs.pop('RIBVRFRouteLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(ARPLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ARPLimitExceeded_ARPLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ARPLimitExceeded = ET.SubElement(config, "ARPLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        ARPLimit = ET.SubElement(ARPLimitExceeded, "ARPLimit")
        ARPLimit.text = kwargs.pop('ARPLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchIdentifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchIdentifier = ET.SubElement(originator_switch_info, "switchIdentifier")
        switchIdentifier.text = kwargs.pop('switchIdentifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchVcsId(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchVcsId = ET.SubElement(originator_switch_info, "switchVcsId")
        switchVcsId.text = kwargs.pop('switchVcsId')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchIpV4Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchIpV4Address = ET.SubElement(originator_switch_info, "switchIpV4Address")
        switchIpV4Address.text = kwargs.pop('switchIpV4Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_originator_switch_info_switchIpV6Address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        originator_switch_info = ET.SubElement(NDLimitExceeded, "originator-switch-info")
        switchIpV6Address = ET.SubElement(originator_switch_info, "switchIpV6Address")
        switchIpV6Address.text = kwargs.pop('switchIpV6Address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def NDLimitExceeded_NDLimit(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        NDLimitExceeded = ET.SubElement(config, "NDLimitExceeded", xmlns="http://brocade.com/ns/brocade-notification-stream")
        NDLimit = ET.SubElement(NDLimitExceeded, "NDLimit")
        NDLimit.text = kwargs.pop('NDLimit')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class ietf_netconf_monitoring(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def netconf_state_datastores_datastore_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name = ET.SubElement(datastore, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_global_lock_global_lock_locked_by_session(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        global_lock = ET.SubElement(lock_type, "global-lock")
        global_lock = ET.SubElement(global_lock, "global-lock")
        locked_by_session = ET.SubElement(global_lock, "locked-by-session")
        locked_by_session.text = kwargs.pop('locked_by_session')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_global_lock_global_lock_locked_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        global_lock = ET.SubElement(lock_type, "global-lock")
        global_lock = ET.SubElement(global_lock, "global-lock")
        locked_time = ET.SubElement(global_lock, "locked-time")
        locked_time.text = kwargs.pop('locked_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_partial_lock_partial_lock_lock_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        partial_lock = ET.SubElement(lock_type, "partial-lock")
        partial_lock = ET.SubElement(partial_lock, "partial-lock")
        lock_id = ET.SubElement(partial_lock, "lock-id")
        lock_id.text = kwargs.pop('lock_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_partial_lock_partial_lock_locked_by_session(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        partial_lock = ET.SubElement(lock_type, "partial-lock")
        partial_lock = ET.SubElement(partial_lock, "partial-lock")
        lock_id_key = ET.SubElement(partial_lock, "lock-id")
        lock_id_key.text = kwargs.pop('lock_id')
        locked_by_session = ET.SubElement(partial_lock, "locked-by-session")
        locked_by_session.text = kwargs.pop('locked_by_session')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_partial_lock_partial_lock_locked_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        partial_lock = ET.SubElement(lock_type, "partial-lock")
        partial_lock = ET.SubElement(partial_lock, "partial-lock")
        lock_id_key = ET.SubElement(partial_lock, "lock-id")
        lock_id_key.text = kwargs.pop('lock_id')
        locked_time = ET.SubElement(partial_lock, "locked-time")
        locked_time.text = kwargs.pop('locked_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_transaction_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        transaction_id = ET.SubElement(datastore, "transaction-id", xmlns="http://tail-f.com/yang/netconf-monitoring")
        transaction_id.text = kwargs.pop('transaction_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_identifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        version_key = ET.SubElement(schema, "version")
        version_key.text = kwargs.pop('version')
        format_key = ET.SubElement(schema, "format")
        format_key.text = kwargs.pop('format')
        identifier = ET.SubElement(schema, "identifier")
        identifier.text = kwargs.pop('identifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        identifier_key = ET.SubElement(schema, "identifier")
        identifier_key.text = kwargs.pop('identifier')
        format_key = ET.SubElement(schema, "format")
        format_key.text = kwargs.pop('format')
        version = ET.SubElement(schema, "version")
        version.text = kwargs.pop('version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_format(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        identifier_key = ET.SubElement(schema, "identifier")
        identifier_key.text = kwargs.pop('identifier')
        version_key = ET.SubElement(schema, "version")
        version_key.text = kwargs.pop('version')
        format = ET.SubElement(schema, "format")
        format.text = kwargs.pop('format')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_namespace(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        identifier_key = ET.SubElement(schema, "identifier")
        identifier_key.text = kwargs.pop('identifier')
        version_key = ET.SubElement(schema, "version")
        version_key.text = kwargs.pop('version')
        format_key = ET.SubElement(schema, "format")
        format_key.text = kwargs.pop('format')
        namespace = ET.SubElement(schema, "namespace")
        namespace.text = kwargs.pop('namespace')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id = ET.SubElement(session, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_transport(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        transport = ET.SubElement(session, "transport")
        transport.text = kwargs.pop('transport')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        username = ET.SubElement(session, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        source_host = ET.SubElement(session, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_login_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        login_time = ET.SubElement(session, "login-time")
        login_time.text = kwargs.pop('login_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_in_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        in_rpcs = ET.SubElement(session, "in-rpcs")
        in_rpcs.text = kwargs.pop('in_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_in_bad_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        in_bad_rpcs = ET.SubElement(session, "in-bad-rpcs")
        in_bad_rpcs.text = kwargs.pop('in_bad_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_out_rpc_errors(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        out_rpc_errors = ET.SubElement(session, "out-rpc-errors")
        out_rpc_errors.text = kwargs.pop('out_rpc_errors')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_out_notifications(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        out_notifications = ET.SubElement(session, "out-notifications")
        out_notifications.text = kwargs.pop('out_notifications')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_netconf_start_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        netconf_start_time = ET.SubElement(statistics, "netconf-start-time")
        netconf_start_time.text = kwargs.pop('netconf_start_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_bad_hellos(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_bad_hellos = ET.SubElement(statistics, "in-bad-hellos")
        in_bad_hellos.text = kwargs.pop('in_bad_hellos')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_sessions(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_sessions = ET.SubElement(statistics, "in-sessions")
        in_sessions.text = kwargs.pop('in_sessions')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_dropped_sessions(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        dropped_sessions = ET.SubElement(statistics, "dropped-sessions")
        dropped_sessions.text = kwargs.pop('dropped_sessions')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_rpcs = ET.SubElement(statistics, "in-rpcs")
        in_rpcs.text = kwargs.pop('in_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_bad_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_bad_rpcs = ET.SubElement(statistics, "in-bad-rpcs")
        in_bad_rpcs.text = kwargs.pop('in_bad_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_out_rpc_errors(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        out_rpc_errors = ET.SubElement(statistics, "out-rpc-errors")
        out_rpc_errors.text = kwargs.pop('out_rpc_errors')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_out_notifications(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        out_notifications = ET.SubElement(statistics, "out-notifications")
        out_notifications.text = kwargs.pop('out_notifications')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name = ET.SubElement(file, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_creator(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name_key = ET.SubElement(file, "name")
        name_key.text = kwargs.pop('name')
        creator = ET.SubElement(file, "creator")
        creator.text = kwargs.pop('creator')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_created(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name_key = ET.SubElement(file, "name")
        name_key.text = kwargs.pop('name')
        created = ET.SubElement(file, "created")
        created.text = kwargs.pop('created')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_context(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name_key = ET.SubElement(file, "name")
        name_key.text = kwargs.pop('name')
        context = ET.SubElement(file, "context")
        context.text = kwargs.pop('context')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_schema_input_identifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_schema = ET.Element("get_schema")
        config = get_schema
        input = ET.SubElement(get_schema, "input")
        identifier = ET.SubElement(input, "identifier")
        identifier.text = kwargs.pop('identifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_schema_input_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_schema = ET.Element("get_schema")
        config = get_schema
        input = ET.SubElement(get_schema, "input")
        version = ET.SubElement(input, "version")
        version.text = kwargs.pop('version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_schema_input_format(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_schema = ET.Element("get_schema")
        config = get_schema
        input = ET.SubElement(get_schema, "input")
        format = ET.SubElement(input, "format")
        format.text = kwargs.pop('format')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name = ET.SubElement(datastore, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_global_lock_global_lock_locked_by_session(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        global_lock = ET.SubElement(lock_type, "global-lock")
        global_lock = ET.SubElement(global_lock, "global-lock")
        locked_by_session = ET.SubElement(global_lock, "locked-by-session")
        locked_by_session.text = kwargs.pop('locked_by_session')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_global_lock_global_lock_locked_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        global_lock = ET.SubElement(lock_type, "global-lock")
        global_lock = ET.SubElement(global_lock, "global-lock")
        locked_time = ET.SubElement(global_lock, "locked-time")
        locked_time.text = kwargs.pop('locked_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_partial_lock_partial_lock_lock_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        partial_lock = ET.SubElement(lock_type, "partial-lock")
        partial_lock = ET.SubElement(partial_lock, "partial-lock")
        lock_id = ET.SubElement(partial_lock, "lock-id")
        lock_id.text = kwargs.pop('lock_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_partial_lock_partial_lock_locked_by_session(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        partial_lock = ET.SubElement(lock_type, "partial-lock")
        partial_lock = ET.SubElement(partial_lock, "partial-lock")
        lock_id_key = ET.SubElement(partial_lock, "lock-id")
        lock_id_key.text = kwargs.pop('lock_id')
        locked_by_session = ET.SubElement(partial_lock, "locked-by-session")
        locked_by_session.text = kwargs.pop('locked_by_session')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_locks_lock_type_partial_lock_partial_lock_locked_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        locks = ET.SubElement(datastore, "locks")
        lock_type = ET.SubElement(locks, "lock-type")
        partial_lock = ET.SubElement(lock_type, "partial-lock")
        partial_lock = ET.SubElement(partial_lock, "partial-lock")
        lock_id_key = ET.SubElement(partial_lock, "lock-id")
        lock_id_key.text = kwargs.pop('lock_id')
        locked_time = ET.SubElement(partial_lock, "locked-time")
        locked_time.text = kwargs.pop('locked_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_datastores_datastore_transaction_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        datastores = ET.SubElement(netconf_state, "datastores")
        datastore = ET.SubElement(datastores, "datastore")
        name_key = ET.SubElement(datastore, "name")
        name_key.text = kwargs.pop('name')
        transaction_id = ET.SubElement(datastore, "transaction-id", xmlns="http://tail-f.com/yang/netconf-monitoring")
        transaction_id.text = kwargs.pop('transaction_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_identifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        version_key = ET.SubElement(schema, "version")
        version_key.text = kwargs.pop('version')
        format_key = ET.SubElement(schema, "format")
        format_key.text = kwargs.pop('format')
        identifier = ET.SubElement(schema, "identifier")
        identifier.text = kwargs.pop('identifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        identifier_key = ET.SubElement(schema, "identifier")
        identifier_key.text = kwargs.pop('identifier')
        format_key = ET.SubElement(schema, "format")
        format_key.text = kwargs.pop('format')
        version = ET.SubElement(schema, "version")
        version.text = kwargs.pop('version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_format(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        identifier_key = ET.SubElement(schema, "identifier")
        identifier_key.text = kwargs.pop('identifier')
        version_key = ET.SubElement(schema, "version")
        version_key.text = kwargs.pop('version')
        format = ET.SubElement(schema, "format")
        format.text = kwargs.pop('format')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_schemas_schema_namespace(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        schemas = ET.SubElement(netconf_state, "schemas")
        schema = ET.SubElement(schemas, "schema")
        identifier_key = ET.SubElement(schema, "identifier")
        identifier_key.text = kwargs.pop('identifier')
        version_key = ET.SubElement(schema, "version")
        version_key.text = kwargs.pop('version')
        format_key = ET.SubElement(schema, "format")
        format_key.text = kwargs.pop('format')
        namespace = ET.SubElement(schema, "namespace")
        namespace.text = kwargs.pop('namespace')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_session_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id = ET.SubElement(session, "session-id")
        session_id.text = kwargs.pop('session_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_transport(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        transport = ET.SubElement(session, "transport")
        transport.text = kwargs.pop('transport')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_username(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        username = ET.SubElement(session, "username")
        username.text = kwargs.pop('username')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_source_host(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        source_host = ET.SubElement(session, "source-host")
        source_host.text = kwargs.pop('source_host')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_login_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        login_time = ET.SubElement(session, "login-time")
        login_time.text = kwargs.pop('login_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_in_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        in_rpcs = ET.SubElement(session, "in-rpcs")
        in_rpcs.text = kwargs.pop('in_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_in_bad_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        in_bad_rpcs = ET.SubElement(session, "in-bad-rpcs")
        in_bad_rpcs.text = kwargs.pop('in_bad_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_out_rpc_errors(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        out_rpc_errors = ET.SubElement(session, "out-rpc-errors")
        out_rpc_errors.text = kwargs.pop('out_rpc_errors')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_sessions_session_out_notifications(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        sessions = ET.SubElement(netconf_state, "sessions")
        session = ET.SubElement(sessions, "session")
        session_id_key = ET.SubElement(session, "session-id")
        session_id_key.text = kwargs.pop('session_id')
        out_notifications = ET.SubElement(session, "out-notifications")
        out_notifications.text = kwargs.pop('out_notifications')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_netconf_start_time(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        netconf_start_time = ET.SubElement(statistics, "netconf-start-time")
        netconf_start_time.text = kwargs.pop('netconf_start_time')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_bad_hellos(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_bad_hellos = ET.SubElement(statistics, "in-bad-hellos")
        in_bad_hellos.text = kwargs.pop('in_bad_hellos')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_sessions(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_sessions = ET.SubElement(statistics, "in-sessions")
        in_sessions.text = kwargs.pop('in_sessions')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_dropped_sessions(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        dropped_sessions = ET.SubElement(statistics, "dropped-sessions")
        dropped_sessions.text = kwargs.pop('dropped_sessions')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_rpcs = ET.SubElement(statistics, "in-rpcs")
        in_rpcs.text = kwargs.pop('in_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_in_bad_rpcs(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        in_bad_rpcs = ET.SubElement(statistics, "in-bad-rpcs")
        in_bad_rpcs.text = kwargs.pop('in_bad_rpcs')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_out_rpc_errors(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        out_rpc_errors = ET.SubElement(statistics, "out-rpc-errors")
        out_rpc_errors.text = kwargs.pop('out_rpc_errors')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_statistics_out_notifications(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        statistics = ET.SubElement(netconf_state, "statistics")
        out_notifications = ET.SubElement(statistics, "out-notifications")
        out_notifications.text = kwargs.pop('out_notifications')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name = ET.SubElement(file, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_creator(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name_key = ET.SubElement(file, "name")
        name_key.text = kwargs.pop('name')
        creator = ET.SubElement(file, "creator")
        creator.text = kwargs.pop('creator')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_created(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name_key = ET.SubElement(file, "name")
        name_key.text = kwargs.pop('name')
        created = ET.SubElement(file, "created")
        created.text = kwargs.pop('created')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def netconf_state_files_file_context(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        netconf_state = ET.SubElement(config, "netconf-state", xmlns="urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring")
        files = ET.SubElement(netconf_state, "files", xmlns="http://tail-f.com/yang/netconf-monitoring")
        file = ET.SubElement(files, "file")
        name_key = ET.SubElement(file, "name")
        name_key.text = kwargs.pop('name')
        context = ET.SubElement(file, "context")
        context.text = kwargs.pop('context')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_schema_input_identifier(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_schema = ET.Element("get_schema")
        config = get_schema
        input = ET.SubElement(get_schema, "input")
        identifier = ET.SubElement(input, "identifier")
        identifier.text = kwargs.pop('identifier')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_schema_input_version(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_schema = ET.Element("get_schema")
        config = get_schema
        input = ET.SubElement(get_schema, "input")
        version = ET.SubElement(input, "version")
        version.text = kwargs.pop('version')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_schema_input_format(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_schema = ET.Element("get_schema")
        config = get_schema
        input = ET.SubElement(get_schema, "input")
        format = ET.SubElement(input, "format")
        format.text = kwargs.pop('format')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_system(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def get_system_uptime_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        input = ET.SubElement(get_system_uptime, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_days(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        days = ET.SubElement(show_system_uptime, "days")
        days.text = kwargs.pop('days')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_hours(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        hours = ET.SubElement(show_system_uptime, "hours")
        hours.text = kwargs.pop('hours')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_minutes(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        minutes = ET.SubElement(show_system_uptime, "minutes")
        minutes.text = kwargs.pop('minutes')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_seconds(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        seconds = ET.SubElement(show_system_uptime, "seconds")
        seconds.text = kwargs.pop('seconds')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_cmd_error(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        cmd_error = ET.SubElement(output, "cmd-error")
        cmd_error.text = kwargs.pop('cmd_error')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        input = ET.SubElement(get_system_uptime, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_days(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        days = ET.SubElement(show_system_uptime, "days")
        days.text = kwargs.pop('days')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_hours(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        hours = ET.SubElement(show_system_uptime, "hours")
        hours.text = kwargs.pop('hours')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_minutes(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        minutes = ET.SubElement(show_system_uptime, "minutes")
        minutes.text = kwargs.pop('minutes')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_show_system_uptime_seconds(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        show_system_uptime = ET.SubElement(output, "show-system-uptime")
        rbridge_id_key = ET.SubElement(show_system_uptime, "rbridge-id")
        rbridge_id_key.text = kwargs.pop('rbridge_id')
        seconds = ET.SubElement(show_system_uptime, "seconds")
        seconds.text = kwargs.pop('seconds')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_system_uptime_output_cmd_error(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_system_uptime = ET.Element("get_system_uptime")
        config = get_system_uptime
        output = ET.SubElement(get_system_uptime, "output")
        cmd_error = ET.SubElement(output, "cmd-error")
        cmd_error.text = kwargs.pop('cmd_error')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_bprate_limit(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def bp_rate_limit_heavy_bp_rate_limit_slot_bp_rate_limit_slot_num(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        bp_rate_limit = ET.SubElement(config, "bp-rate-limit", xmlns="urn:brocade.com:mgmt:brocade-bprate-limit")
        heavy = ET.SubElement(bp_rate_limit, "heavy")
        bp_rate_limit_slot = ET.SubElement(heavy, "bp-rate-limit-slot")
        bp_rate_limit_slot_num = ET.SubElement(bp_rate_limit_slot, "bp-rate-limit-slot-num")
        bp_rate_limit_slot_num.text = kwargs.pop('bp_rate_limit_slot_num')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def bp_rate_limit_heavy_bp_rate_limit_slot_bp_rate_limit_slot_num(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        bp_rate_limit = ET.SubElement(config, "bp-rate-limit", xmlns="urn:brocade.com:mgmt:brocade-bprate-limit")
        heavy = ET.SubElement(bp_rate_limit, "heavy")
        bp_rate_limit_slot = ET.SubElement(heavy, "bp-rate-limit-slot")
        bp_rate_limit_slot_num = ET.SubElement(bp_rate_limit_slot, "bp-rate-limit-slot-num")
        bp_rate_limit_slot_num.text = kwargs.pop('bp_rate_limit_slot_num')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET
from pynos.versions.base.yang.brocade_rbridge import brocade_rbridge
import pynos.utilities


class System(object):
    """
    System class containing all system level methods and attributes.
    """
    def __init__(self, callback):
        """System init method.

        Args:
            callback: Callback function that will be called for each action.

        Returns:
            System Object

        Raises:
            None
        """
        self._callback = callback
        self._rbridge = brocade_rbridge(callback=pynos.utilities.return_xml)

    @property
    def uptime(self):
        """dict: device uptime
        """
        namespace = 'urn:brocade.com:mgmt:brocade-system'
        get_system_uptime = ET.Element('get-system-uptime', xmlns=namespace)
        results = self._callback(get_system_uptime, handler='get')
        system_uptime = dict(days=results.find('.//{%s}days' % namespace).text,
                             hours=results.find('.//{%s}hours' %
                                                namespace).text,
                             minutes=results.find('.//{%s}minutes' %
                                                  namespace).text,
                             seconds=results.find('.//{%s}seconds' %
                                                  namespace).text)
        return system_uptime

    def chassis_name(self, **kwargs):
        """Get device's chassis name/Model.

        Args:
            rbridge_id (str): The rbridge ID of the device
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `rbridge_id` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.system.chassis_name(rbridge_id='225')
            ...     assert output == 'VDX6740'
        """
        namespace = "urn:brocade.com:mgmt:brocade-rbridge"
        rbridge_id = kwargs.pop('rbridge_id', '1')
        chassis_name = ' '
        callback = kwargs.pop('callback', self._callback)
        rid_args = dict(rbridge_id=rbridge_id, chassis_name=chassis_name)
        rid = getattr(self._rbridge,
                      'rbridge_id_switch_attributes_chassis_name')
        config = rid(**rid_args)
        output = callback(config, handler='get_config')
        chassis_name = output.data.find('.//{%s}chassis-name' % namespace).text
        return chassis_name

    def router_id(self, **kwargs):
        """Configures device's Router ID.

        Args:
            router_id (str): Router ID for the device.
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `router_id` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.system.router_id(router_id='10.24.39.211',
            ...     rbridge_id='225')
            ...     dev.system.router_id() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        router_id = kwargs.pop('router_id')
        rbridge_id = kwargs.pop('rbridge_id', '1')
        callback = kwargs.pop('callback', self._callback)
        rid_args = dict(rbridge_id=rbridge_id, router_id=router_id)
        config = self._rbridge.rbridge_id_ip_rtm_config_router_id(**rid_args)
        return callback(config)

    def rbridge_id(self, **kwargs):
        """Configures device's rbridge ID. Setting this property will need
        a switch reboot

        Args:
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            get (bool): Get config instead of editing config. (True, False)
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `rbridge_id` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.system.rbridge_id(rbridge_id='225')
            ...     output = dev.system.rbridge_id(rbridge_id='225', get=True)
            ...     dev.system.rbridge_id() # doctest: +IGNORE_EXCEPTION_DETAIL
            Traceback (most recent call last):
            KeyError
        """
        is_get_config = kwargs.pop('get', False)
        if not is_get_config:
            rbridge_id = kwargs.pop('rbridge_id')
        else:
            rbridge_id = ''
        callback = kwargs.pop('callback', self._callback)
        rid_args = dict(rbridge_id=rbridge_id)
        rid = getattr(self._rbridge,
                      'rbridge_id_rbridge_id')
        config = rid(**rid_args)
        if is_get_config:
            return callback(config, handler='get_config')
        return callback(config)

    def host_name(self, **kwargs):
        """Configures device's host name.

        Args:
            rbridge_id (str): The rbridge ID of the device on which BGP will be
                configured in a VCS fabric.
            host_name (str): The host name of the device.
            get (bool): Get config instead of editing config. (True, False)
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.

        Raises:
            KeyError: if `rbridge_id` is not specified.

        Examples:
            >>> import pynos.device
            >>> conn = ('10.24.39.211', '22')
            >>> auth = ('admin', 'password')
            >>> with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...     output = dev.system.host_name(rbridge_id='225',
            ...     host_name='sw0')
            ...     output = dev.system.host_name(rbridge_id='225', get=True)
            ...     try:
            ...         conf = output.data.find('.//{*}host-name').text
            ...     except AttributeError:
            ...         conf = None
            ...     assert conf == 'sw0'
        """
        is_get_config = kwargs.pop('get', False)
        rbridge_id = kwargs.pop('rbridge_id')
        if not is_get_config:
            host_name = kwargs.pop('host_name', 'sw0')
        else:
            host_name = ' '
        callback = kwargs.pop('callback', self._callback)
        rid_args = dict(rbridge_id=rbridge_id, host_name=host_name)
        rid = getattr(self._rbridge,
                      'rbridge_id_switch_attributes_host_name')
        config = rid(**rid_args)
        if is_get_config:
            return callback(config, handler='get_config')
        return callback(config)



"""
Copyright 2015 Brocade Communications Systems, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
    http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET
import pynos.utilities

from pynos.versions.base.yang.brocade_vcs import brocade_vcs
from ipaddress import ip_interface


class VCS(object):
    """
    VCS class containing all VCS methods and attributes.
    """

    def __init__(self, callback):
        """VCS init method.
        Args:
            callback: Callback function that will be called for each action.
        Returns:
            VCS Object
        Raises:
            None
        """
        self._callback = callback
        self._vcs = brocade_vcs(
            callback=pynos.utilities.return_xml
        )

    @property
    def vcs_nodes(self):
        """dict: vcs node details
        """
        urn = "{urn:brocade.com:mgmt:brocade-vcs}"
        namespace = 'urn:brocade.com:mgmt:brocade-vcs'
        show_vcs = ET.Element('show-vcs', xmlns=namespace)
        results = self._callback(show_vcs, handler='get')
        result = []
        for nodes in results.findall('%svcs-nodes' % urn):
            for item in nodes.findall('%svcs-node-info' % urn):
                serial_number = item.find('%snode-serial-num' % urn).text
                node_status = item.find('%snode-status' % urn).text
                vcs_id = item.find('%snode-vcs-id' % urn).text
                rbridge_id = item.find('%snode-rbridge-id' % urn).text
                switch_mac = item.find('%snode-switch-mac' % urn).text
                switch_wwn = item.find('%snode-switch-wwn' % urn).text
                switch_name = item.find('%snode-switchname' % urn).text
                node_is_principal = item.find('%snode-is-principal' % urn).text
                switch_ip = ''
                for switch_ip_addr in item.findall(
                        '%snode-public-ip-addresses' % urn):
                    switch_ip = switch_ip_addr.find(
                        '%snode-public-ip-address' % urn).text
                    break
                item_results = {'node-serial-num': serial_number,
                                'node-status': node_status,
                                'node-vcs-id': vcs_id,
                                'node-rbridge-id': rbridge_id,
                                'node-switch-mac': switch_mac,
                                'node-switch-wwn': switch_wwn,
                                'node-switch-ip': switch_ip,
                                'node-switchname': switch_name,
                                'node-is-principal': node_is_principal}

                result.append(item_results)

        return result

    def vcs_vip(self, **kwargs):
        """Set VCS Virtual IP.

        Args:
            vip (str): IPv4/IPv6 Virtual IP Address.
            rbridge_id (str): rbridge-id for device. Only required when type is
                `ve`.
            delete (bool): Deletes the virtual ip if `delete` is ``True``.
            get (bool): Get config instead of editing config. (True, False)
            callback (function): A function executed upon completion of the
                method.  The only parameter passed to `callback` will be the
                ``ElementTree`` `config`.

        Returns:
            Return value of `callback`.
        Raises:
            KeyError: if `vip` is not passed.
            ValueError: if `vip` is invalid.

        Examples:
            >>> import pynos.device
            >>> switches = ['10.24.39.211', '10.24.39.203']
            >>> auth = ('admin', 'password')
            >>> for switch in switches:
            ...     conn = (switch, '22')
            ...     with pynos.device.Device(conn=conn, auth=auth) as dev:
            ...         dev.interface.vcs_vip(vip='10.1.1.1/24')
            ...         dev.interface.vcs_vip(vip='fe80::cafe:beef:1000:1/64')
            ...         dev.interface.vcs_vip(vip='10.1.1.1/24',get=True)
            ...         dev.interface.vcs_vip(vip='fe80::cafe:beef:1000:1/64',
            ...                               get=True)
            ...         dev.interface.vcs_vip(vip='fe80::cafe:beef:1000:1/64',
            ...                               delete=True)
            ...         dev.interface.vcs_vip(vip='10.1.1.1/24',get=True)
            ...         dev.interface.vcs_vip(vip='fe80::cafe:beef:1000:1/64',
            ...                               get=True)
            ...         dev.interface.vcs_vip(vip='10.1.1.1/24',delete=True)
            ...         dev.interface.vcs_vip(vip='fe80::cafe:beef:1000:1/64',
            ...                               delete=True)
        """

        get_config = kwargs.pop('get', False)
        delete = kwargs.pop('delete', False)
        callback = kwargs.pop('callback', self._callback)
        method_class = self._vcs

        if not get_config:
            vip = str(kwargs.pop('vip'))
            ipaddress = ip_interface(unicode(vip))
            vcs_vip = None

            if ipaddress.version == 4:
                method_name = 'vcs_virtual_ip_address_address'
                vcs_args = dict(address=vip)
                vcs_vip = getattr(method_class, method_name)
            elif ipaddress.version == 6:
                method_name = 'vcs_virtual_ipv6_address_ipv6address'
                vcs_args = dict(ipv6address=vip)
                vcs_vip = getattr(method_class, method_name)

            if not delete:
                config = vcs_vip(**vcs_args)
            else:
                if ipaddress.version == 4:
                    config = vcs_vip(**vcs_args)
                    config.find('.//*address').set('operation', 'delete')
                elif ipaddress.version == 6:
                    config = vcs_vip(**vcs_args)
                    config.find('.//*ipv6address').set('operation', 'delete')

        elif get_config:
            vip_info = {}

            method_name = 'vcs_virtual_ip_address_address'
            vcs_args = dict(address='')
            vcs_vip = getattr(method_class, method_name)
            config = vcs_vip(**vcs_args)
            vip_info['ipv4_vip'] = callback(config, handler='get_config')

            method_name = 'vcs_virtual_ipv6_address_ipv6address'
            vcs_args = dict(ipv6address='')
            vcs_vip = getattr(method_class, method_name)
            config = vcs_vip(**vcs_args)
            vip_info['ipv6_vip'] = callback(config, handler='get_config')
            return vip_info

        return callback(config)
